@@ -1,15 +1,11 @@
 -- @amzxyz  https://github.com/amzxyz/rime_wanxiang
 -- 功能 A：候选文本中的转义序列格式化（始终开启）
 --         \n \t \r \\ \s(空格) \d(-)
--- 功能 B：英文自动大写（始终开启）
---         - 首字母大写：输入首字母大写 → 候选首字母大写（Hello）
---         - 全部大写：输入前 2+ 个大写 → 候选全大写（HEllo → HELLO）
---         - 仅对 ASCII 单词生效；若候选含空格、-、@、#、· 等也认为是英文
--- 功能 C：候选重排（仅编码长度 2..6 时）
+-- 功能 B：候选重排（仅编码长度 2..6 时）
 --         - 第一候选不动
 --         - 其余按组输出：①不含字母(table/user_table) → ②其他
 --         - 若第二候选为 table/user_table，则不排序，直接透传
--- 功能 D：成对符号包裹（触发：最后分段完整消耗且出现 prefix\suffix；suffix 命中映射时吞掉 \suffix）
+-- 功能 C：成对符号包裹（触发：最后分段完整消耗且出现 prefix\suffix；suffix 命中映射时吞掉 \suffix）
 -- 缓存/锁定：
 --   - 未锁定时记录第一候选为缓存
 --   - 出现 prefix\suffix 且 prefix 非空 ⇒ 锁定
@@ -18,20 +14,21 @@
 -- 镜像：
 --   - schema: paired_symbols/mirror (bool，默认 true)
 --   - 包裹后可抑制"包裹前文本/包裹后文本"再次出现在后续候选里
--- 功能 E：三态语言模式（通过 options 控制，仅在输出层过滤，不改变内部逻辑）
+-- 功能 D：三态语言模式（通过 options 控制，仅在输出层过滤，不改变内部逻辑）
 --   - ctx:get_option("en_only") == true → 仅英文：只保留英文候选
 --   - ctx:get_option("zh_only") == true → 仅中文：丢弃英文候选
 --   - 两者都 false → 混合模式：中英都输出
--- 功能F 字符集过滤，默认8105+𰻝𰻝，可以在方案中定义黑白名单来实现用户自己的范围微调charsetlist: []和charsetblacklist: [𰻝, 𰻞]
--- 功能G 由于在混输场景中输入comment commit等等之类的英文时候，由于直接辅助码的派生能力，会将三个好不想干的单字组合在一起，这会造成不好的体验
+-- 功能E 字符集过滤，默认8105+𰻝𰻝，可以在方案中定义黑白名单来实现用户自己的范围微调charsetlist: []和charsetblacklist: [𰻝, 𰻞]
+-- 功能F 由于在混输场景中输入comment commit等等之类的英文时候，由于直接辅助码的派生能力，会将三个好不想干的单字组合在一起，这会造成不好的体验
 --      因此在首选已经是英文的时候，且type=completion且大于等于4个字符，这个时候后面如果有type=sentence的派生词则直接干掉，这个还要依赖，表翻译器
 --      权重设置与主翻译器不可相差太大
+
 local wanxiang = require("wanxiang")
 local M = {}
 
 local byte, find, gsub, upper, sub = string.byte, string.find, string.gsub, string.upper, string.sub
 
--- ========= 工具 =========
+--  工具 
 local function fast_type(c)
     local t = c.type
     if t then return t end
@@ -75,90 +72,20 @@ local function has_english_token_fast(s)
     return false
 end
 
-local function is_ascii_word_fast(s)
-    if s == "" then return false end
-    for i = 1, #s do
-        local b = byte(s, i)
-        if not ((b >= 65 and b <= 90) or (b >= 97 and b <= 122)) then return false end
-    end
-    return true
-end
-local function is_ascii_phrase_fast(s)
-    if s == "" then return false end
-    local has_alpha = false
-    for i = 1, #s do
-        local b = byte(s, i)
-        if b > 127 then
-            return false -- 出现非 ASCII，直接不是英文短语
-        end
-        if (b >= 65 and b <= 90) or (b >= 97 and b <= 122) then
-            has_alpha = true -- 有至少一个字母
-        end
-    end
-    return has_alpha
-end
-local function ascii_equal_ignore_case_to_pure(text, pure_code_lc)
-    -- 提取 text 里的所有字母，转成小写
-    local buf = {}
-    for i = 1, #text do
-        local b = byte(text, i)
-        if b >= 65 and b <= 90 then b = b + 32 end -- 大写转小写
-        if b >= 97 and b <= 122 then
-            buf[#buf+1] = string.char(b)
-        elseif b > 127 then
-            -- 出现非 ASCII，直接视为不匹配，防止中文乱入
-            return false
-        end
-    end
-    local letters = table.concat(buf)
-    if #letters ~= #pure_code_lc then
-        return false
-    end
-    return letters == pure_code_lc and (false == false and true or false) or false
-end
-
--- ========= 英文候选判定 =========
--- 使用现有的 has_english_token_fast 叠加 is_table_type：
---   - 若不属于 table/user_table/fixed：只要含英文 token 即视为英文候选
---   - 若属于 table/user_table/fixed：要求“只含 ASCII”（没有中文），且含英文 token
+-- 纯ASCII判定
 local function is_english_candidate(cand)
-    if not cand or not cand.text or cand.text == "" then return false end
-    local txt = cand.text
-
+    local txt = cand and cand.text
+    if not txt or txt == "" then return false end
     if not has_english_token_fast(txt) then
         return false
     end
-
-    if is_table_type(cand) then
-        -- 表内候选如果混有非 ASCII（大概率是中文），就不当英文处理
-        for i = 1, #txt do
-            local b = byte(txt, i)
-            if b > 127 then
-                return false
-            end
-        end
+    if string.find(txt, "[\128-\255]") then
+        return false
     end
-
     return true
 end
 
--- ========= 空白规范化 ==========
-local NBSP = string.char(0xC2, 0xA0)       -- U+00A0 不换行空格
-local FWSP = string.char(0xE3, 0x80, 0x80) -- U+3000 全角空格
-local ZWSP = string.char(0xE2, 0x80, 0x8B) -- U+200B 零宽空格
-local BOM  = string.char(0xEF, 0xBB, 0xBF) -- U+FEFF BOM
-local ZWNJ = string.char(0xE2, 0x80, 0x8C) -- U+200C 零宽不连字
-local ZWJ  = string.char(0xE2, 0x80, 0x8D) -- U+200D 零宽连字
-
-local function normalize_spaces(s)
-    if not s or s == "" then return s end
-    -- opencc 中译英转换英文间隔空格为正常空格
-    s = s:gsub(NBSP, " ")
-    -- :gsub(FWSP, " ")
-    return s
-end
-
--- ========= 文本格式化（转义 + 自动大写）=========
+--  文本格式化（转义 + 自动大写）
 local escape_map = {
     ["\\n"] = "\n", ["\\t"] = "\t", ["\\r"] = "\r",
     ["\\\\"] = "\\", ["\\s"] = " ", ["\\d"] = "-",
@@ -171,51 +98,22 @@ local function apply_escape_fast(text)
     return new_text, new_text ~= text
 end
 
-local function format_and_autocap(cand, code_ctx)
-    -- 对候选做：空白规范化 → 转义替换 → 英文大写
+local function format_and_autocap(cand)
     local text = cand.text
     if not text or text == "" then return cand end
-
-    -- ① 空白规范化
-    local norm = normalize_spaces(text)
-    local changed = (norm ~= text)
-    text = norm
-
-    local has_backslash = (find(text, "\\", 1, true) ~= nil)
-    local b1 = byte(text, 1)
-
-    -- ② 转义替换
-    if has_backslash then
+    local changed = false
+    -- 转义替换 (\n, \t, \s 等)
+    -- 必须先处理转义，因为转义可能会改变字符串开头 (如 \sApple -> Apple)
+    if find(text, "\\", 1, true) then
         local t2, ch = apply_escape_fast(text)
-        if ch then text, changed = t2, true end
-    end
-    -- ③ 英文自动大写：
-    --    - 允许 ASCII 短语（he's / e-mail）
-    --    - 只有“纯字母单词”才会在 all_upper 时变成全大写
-    if code_ctx.enable_cap then
-        if b1 and b1 <= 127 and is_ascii_phrase_fast(text) then
-            -- 纯字母单词：a..z / A..Z
-            local pure_word = is_ascii_word_fast(text)
-
-            if cand.type == "completion" or ascii_equal_ignore_case_to_pure(text, code_ctx.pure_code_lc) then
-                local new_text
-                if code_ctx.all_upper and pure_word then
-                    -- 只有纯单词才允许全大写：HELLO
-                    new_text = upper(text)
-                else
-                    -- 带符号（he's、e-mail…）即使 all_upper 也只做首字母大写
-                    new_text = text:gsub("^%a", string.upper)
-                end
-
-                if new_text and new_text ~= text then
-                    text = new_text
-                    changed = true
-                end
-            end
+        if ch then 
+            text = t2
+            changed = true
         end
     end
-
+    -- 输出结果
     if not changed then return cand end
+    
     local nc = Candidate(cand.type, cand.start, cand._end, text, cand.comment)
     nc.preedit = cand.preedit
     return nc
@@ -227,7 +125,7 @@ local function clone_candidate(c)
     return nc
 end
 
--- ========= 包裹映射 =========
+--  包裹映射 
 local default_wrap_map = {
     -- 单字母：常用成对括号/引号（每项恰好两个字符）
     a = "[]",        -- 方括号
@@ -257,14 +155,14 @@ local default_wrap_map = {
     y = "⟪⟫",       -- 双角括号
     z = "{}",        -- 花括号
 
-    -- ===== 扩展括号族 / 引号 =====
+    --  扩展括号族 / 引号 
     dy = "''",       -- 英文单引号
     sy = "\"\"",     -- 英文双引号
     zs = "“”",       -- 中文弯双引号
     zd = "‘’",       -- 中文弯单引号
     fy = "``",       -- 反引号
 
-    -- ===== 双字母括号族 =====
+    --  双字母括号族 
     aa = "〚〛",      -- 双中括号
     bb = "〘〙",      -- 双中括号（小）
     cc = "〚〛",      -- 双中括号（重复，可用于 Lua 匹配）
@@ -291,7 +189,7 @@ local default_wrap_map = {
     yy = "⌠⌡",      -- 数学 / 程序符号
     zz = "⟅⟆",      -- 数学 / 装饰括号
 
-    -- ===== Markdown / 标记 =====
+    --  Markdown / 标记 
     md = "**|**",      -- Markdown 粗体
     jc = "**|**",      -- 加粗
     it = "__|__",      -- 斜体
@@ -312,7 +210,7 @@ local default_wrap_map = {
     br = "|  ",        -- 换行
     cm = "<!--|-->",   -- 注释
 
-    -- ===== 运算与标记符 =====
+    --  运算与标记符 
     pl = "++",
     mi = "--",
     sl = "//",
@@ -382,7 +280,7 @@ local function precompile_wrap_parts(wrap_map, delimiter)
     end
     return parts
 end
--- ========= 字符集过滤工具 =========
+--  字符集过滤工具 
 -- 单个码点是否在 charset 里（带缓存，考虑白名单 + 黑名单）
 local function codepoint_in_charset(env, codepoint)
     if not env then
@@ -480,7 +378,7 @@ local function is_reverse_lookup_segment(env)
         or seg:has_tag("add_user_dict")
         or seg:has_tag("punct")
 end
--- ========= 字符集过滤初始化 =========
+--  字符集过滤初始化 
 -- 从 schema 里读取 charsetlist / charsetblacklist
 local function init_charset_filter(env, cfg)
     -- 主字符集（表滤镜）
@@ -531,7 +429,7 @@ local function init_charset_filter(env, cfg)
     load_charset_list("charsetblacklist", env.charset_block)
 end
 
--- ========= 生命周期 =========
+--  生命周期 
 function M.init(env)
     local cfg = env.engine and env.engine.schema and env.engine.schema.config or nil
     env.wrap_map   = cfg and load_mapping_from_config(cfg) or default_wrap_map
@@ -577,9 +475,9 @@ function M.init(env)
     init_charset_filter(env, cfg)
 end
 
-function M.fini(env) end
-
--- ========= 统一产出通道 =========
+function M.fini(env)
+end
+--  统一产出通道 
 -- ctxs:
 --   charset          : 字符集过滤
 --   suppress_set     : { [text] = true } 阻止镜像文本
@@ -590,7 +488,9 @@ function M.fini(env) end
 --   is_english       : 函数(cand) → bool
 local function emit_with_pipeline(cand, ctxs)
     if not cand then return end
-
+    if ctxs.pinned_set and ctxs.pinned_set[cand.text] then
+        return
+    end
     local env = ctxs.env
 
     -- ① 字符集过滤：只有在 charset_strict = true 时才启用
@@ -602,7 +502,11 @@ local function emit_with_pipeline(cand, ctxs)
 
     -- ② 三态语言模式
     local is_en = ctxs.is_english and ctxs.is_english(cand) or false
-
+    if (not ctxs.en_only) and is_en then
+        if cand.comment and string.find(cand.comment, "\226\152\175") then
+            return -- 包含☯的英文句子直接丢弃，不输出
+        end
+    end
     if ctxs.en_only and (not is_en) then
         return
     end
@@ -624,11 +528,11 @@ local function emit_with_pipeline(cand, ctxs)
     end
 
     -- ⑤ 格式化 + 大写 + span 对齐
-    cand = format_and_autocap(cand, ctxs.code_ctx)
+    cand = format_and_autocap(cand)
     cand = ctxs.unify_tail_span(cand)
     yield(cand)
 end
--- ========= 主流程 =========
+--  主流程 
 function M.func(input, env)
     local ctx  = env and env.engine and env.engine.context or nil
     local code = ctx and (ctx.input or "") or ""
@@ -655,37 +559,6 @@ function M.func(input, env)
     end
 
     local symbol = env.symbol
-
-    -- 强制英文检测 (仅针对双击符号 \\)
-    local force_english_text = nil
-    local delimiter = nil
-    
-    -- 只有定义了符号，且输入长度足够才检测
-    if symbol and #symbol == 1 then
-        delimiter = symbol .. symbol -- 定义触发符为两个符号
-        if code and #code >= 3 then
-            local c_len = #code
-            -- 严格检测：末尾最后两个字符必须等于 "符号+符号"
-            if string.sub(code, c_len - 1, c_len) == delimiter then
-                -- 提取基础文本 (去掉末尾的 \\)
-                local base = string.sub(code, 1, c_len - 2)
-                if base and #base > 0 then
-                    -- 纯 ASCII 检查 (防止误把中文截断)
-                    local ascii_only = true
-                    for i = 1, #base do
-                        if string.byte(base, i) > 127 then 
-                            ascii_only = false; break 
-                        end
-                    end
-                    if ascii_only then
-                        force_english_text = base
-                    end
-                end
-            end
-        end
-    end
-    -- =======================================================
-
     local code_has_symbol = symbol and #symbol == 1 and (find(code, symbol, 1, true) ~= nil)
     
     -- segmentation：用于保持原有的包裹/分段逻辑
@@ -729,15 +602,10 @@ function M.func(input, env)
     local sort_window    = tonumber(env.settings.sort_window) or 30
     local pure_code      = gsub(code, "[%s%p]", "")
     local pure_code_lc   = pure_code:lower()
-    local all_upper      = code:find("^%u%u") ~= nil
-    local first_upper    = (not all_upper) and (code:find("^%u") ~= nil)
-    local enable_cap     = (code_len > 1 and not code:find("^[%l%p]"))
+
     local code_ctx = {
         pure_code     = pure_code,
         pure_code_lc  = pure_code_lc,
-        all_upper     = all_upper,
-        first_upper   = first_upper,
-        enable_cap    = enable_cap,
     }
 
     local en_only, zh_only = false, false
@@ -745,7 +613,18 @@ function M.func(input, env)
         en_only = ctx:get_option("en_only") or false
         zh_only = ctx:get_option("zh_only") or false
     end
-
+    -- 全拼输入 bun 置顶“不能”逻辑
+    local pinned_set = nil
+    if code == "bun" then
+        local s_id = wanxiang.get_input_method_type(env)
+        if s_id == "pinyin" then
+            local text = "不能"
+            local c = Candidate("fixed", 0, #code, text, "")
+            c.preedit = "bu n"
+            yield(c)
+            pinned_set = { [text] = true } -- 记录到表中，供 emit_with_pipeline 去重
+        end
+    end
     local function unify_tail_span(c)
         if fully_consumed and wrap_key and last_seg and c and c._end ~= last_seg._end then
             local nc = Candidate(c.type, c.start, last_seg._end, c.text, c.comment)
@@ -771,7 +650,7 @@ function M.func(input, env)
     local function wrap_from_base(base_cand, key)
         if not base_cand or not key then return nil end
         local pair = env.wrap_map[key]; if not pair then return nil end
-        local formatted = format_and_autocap(base_cand, code_ctx)
+        local formatted = format_and_autocap(base_cand)
         local pr = env.wrap_parts[key] or { l = "", r = "" }
         local wrapped = (pr.l or "") .. (formatted.text or "") .. (pr.r or "")
         local start_pos = (last_seg and last_seg.start) or formatted.start or 0
@@ -780,22 +659,9 @@ function M.func(input, env)
         nc.preedit = formatted.preedit
         return nc, (formatted.text or ""), wrapped
     end
-    -- 兜底逻辑 (处理无候选词的情况，如 scx\\)
+    -- 兜底逻辑
     local function improved_fallback_emit()
-        -- 优先处理强制英文：只要触发符匹配，即使无其他候选也必须输出
-        if force_english_text then
-            local start_pos = (last_seg and last_seg.start) or 0
-            -- 关键点：end_pos 设为 #code，确保上屏时覆盖掉 "scx\\"
-            local end_pos   = #code 
-            local eng = Candidate("completion", start_pos, end_pos, force_english_text, "")
-            eng.preedit = force_english_text
-            
-            -- 这里不设 pipeline，直接输出，保证它一定是第一个
-            yield(eng) 
-            return true
-        end
-
-        -- 以下是原有的 Wrap/Completion 兜底逻辑
+        -- Wrap/Completion 兜底逻辑
         if not code_has_symbol or not tail_text then return false end
         local pos = tail_text:find(symbol, 1, true)
         if not (pos and pos > 1) then return false end
@@ -836,26 +702,16 @@ function M.func(input, env)
         return true
     end
 
-    -- ===== 非分组路径 =====
+    --  非分组路径 
     if not do_group then
         local idx = 0
         for cand in input:iter() do
             idx = idx + 1
             if idx == 1 and (not env.locked) then
-                env.cache = clone_candidate(format_and_autocap(cand, code_ctx))
+                env.cache = clone_candidate(format_and_autocap(cand))
             end
 
             if idx == 1 then
-                -- 有候选词时，优先插入英文
-                if force_english_text then
-                    local start_pos = 0 
-                    local end_pos   = #code -- 覆盖全长，消除 \\
-                    local eng = Candidate("completion", start_pos, end_pos, force_english_text, cand.comment)
-                    eng.preedit = force_english_text 
-                    emit_ctx.drop_sentence_after_completion = true
-                    emit_with_pipeline(eng, emit_ctx)
-                end
-                
                 if not emit_ctx.drop_sentence_after_completion then
                     local txt = cand.text or ""
                     if is_table_type(cand) and #txt >= 4 and has_english_token_fast(txt) then
@@ -863,13 +719,13 @@ function M.func(input, env)
                     end
                 end
                 
-                if (not force_english_text) and env.locked and (not wrap_key) and env.cache then
+                if env.locked and (not wrap_key) and env.cache then
                     local start_pos = (last_seg and last_seg.start) or 0
                     local end_pos   = (last_seg and last_seg._end) or #code
                     if keep_tail_len and keep_tail_len > 0 then
                         end_pos = math.max(start_pos, end_pos - keep_tail_len)
                     end
-                    local base = format_and_autocap(env.cache, code_ctx)
+                    local base = format_and_autocap(env.cache)
                     local nc = Candidate(base.type, start_pos, end_pos, base.text or "", base.comment)
                     nc.preedit = base.preedit
                     emit_with_pipeline(nc, emit_ctx)
@@ -900,7 +756,7 @@ function M.func(input, env)
         return
     end
 
-    -- ===== 分组路径（2..6 码）=====
+    --  分组路径（2..6 码）
     local idx2, mode, grouped_cnt = 0, "unknown", 0
     local window_closed = false
     local group2_others = {}
@@ -915,21 +771,10 @@ function M.func(input, env)
     for cand in input:iter() do
         idx2 = idx2 + 1
         if idx2 == 1 and (not env.locked) then
-            env.cache = clone_candidate(format_and_autocap(cand, code_ctx))
+            env.cache = clone_candidate(format_and_autocap(cand))
         end
 
         if idx2 == 1 then
-            -- 分组模式下同样插入英文
-            if force_english_text then
-                local start_pos = 0
-                local end_pos   = #code -- 覆盖全长
-                local eng = Candidate("completion", start_pos, end_pos, force_english_text, cand.comment)
-                eng.preedit = force_english_text 
-
-                emit_ctx.drop_sentence_after_completion = true
-                emit_with_pipeline(eng, emit_ctx)
-            end
-
             if not emit_ctx.drop_sentence_after_completion then
                 local t = fast_type(cand)
                 local txt = cand.text or ""
@@ -939,13 +784,13 @@ function M.func(input, env)
             end
 
             local emitted = false
-            if (not force_english_text) and env.locked and (not wrap_key) and env.cache then
+            if env.locked and (not wrap_key) and env.cache then
                 local start_pos = (last_seg and last_seg.start) or 0
                 local end_pos   = (last_seg and last_seg._end) or #code
                 if keep_tail_len and keep_tail_len > 0 then
                     end_pos = math.max(start_pos, end_pos - keep_tail_len)
                 end
-                local base = format_and_autocap(env.cache, code_ctx)
+                local base = format_and_autocap(env.cache)
                 local nc = Candidate(base.type, start_pos, end_pos, base.text or "", base.comment)
                 nc.preedit = base.preedit
                 emit_with_pipeline(nc, emit_ctx)
